The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

This project uses [Semantic Versioning](https://semver.org/) - MAJOR.MINOR.PATCH

# Changelog

## v0.1.0 (2026-03-06)


### Fixed

- Use salt-call from the salt bundle with transactional_update module on executing actions inside transactions.
  [#2](https://github.com/salt-extensions/saltext-transactional-update/pull/2)
